@@ -145,7 +145,7 @@ struct NautilusViewClass {
 	/* get_backing uri is a function pointer for subclasses to
 	 * override. Subclasses may replace it with a function that
 	 * returns the URI for the location where to create new folders,
-	 * files, links, launchers, and paste the clipboard to.
+	 * files, links and paste the clipboard to.
 	 */
 
 	char *	(* get_backing_uri)		(NautilusView *view);
@@ -329,6 +329,9 @@ void                nautilus_view_activate_files                   (NautilusView
 								    GList                  *files,
 								    NautilusWindowOpenFlags flags,
 								    gboolean                confirm_multiple);
+void                nautilus_view_preview_files                    (NautilusView        *view,
+								    GList               *files,
+								    GArray              *locations);
 void                nautilus_view_start_batching_selection_changes (NautilusView  *view);
 void                nautilus_view_stop_batching_selection_changes  (NautilusView  *view);
 void                nautilus_view_notify_selection_changed         (NautilusView  *view);
